@@ -11,7 +11,7 @@ CHOICES=[('Morning', 'Morning'),
 class DemoForm(forms.Form):
     first_possibility = forms.DateField(label=_("First"), widget=forms.TextInput(attrs={'placeholder': 'first_possibility*(YYYY-MM-DD)','class':'form-control'}))
     first = forms.ChoiceField(choices=CHOICES, widget=forms.RadioSelect(attrs={'class': 'unstyled'}))
-    second_possibility = forms.DateField(label=_("Second"), widget=forms.TextInput(attrs={'placeholder': 'Second possiblity*(YYYY-MM-DD)', 'class':'form-control'}), required=False)
+    second_possibility = forms.DateField(label=_("Second"), widget=forms.TextInput(attrs={'placeholder': 'Second possiblity(YYYY-MM-DD)', 'class':'form-control'}), required=False)
     second = forms.ChoiceField(choices=CHOICES, widget=forms.RadioSelect(attrs={'class': 'unstyled'}), required=False)
     name = forms.CharField(label=_("Name"), widget=forms.TextInput(attrs={'placeholder': 'Your name*', 'class':'form-control'}))
     email = forms.EmailField(label=_("Email"), widget=forms.TextInput(attrs={'placeholder': 'Your email address*', 'class':'form-control'}))
